diff --git a/apps/files_encryption/ajax/adminrecovery.php b/apps/files_encryption/ajax/adminrecovery.php
index 684fd51ae136543c299ef6943bfb72272fc97f1e..503c15b53a9d01ffeacdd0256ef01bd20b6c4cc0 100644
--- a/apps/files_encryption/ajax/adminrecovery.php
+++ b/apps/files_encryption/ajax/adminrecovery.php
@@ -7,7 +7,8 @@
  *
  * Script to handle admin settings for encrypted key recovery
  */
-use OCA\Encryption;
+
+use OCA\Files_Encryption\Helper;
 
 \OCP\JSON::checkAdminUser();
 \OCP\JSON::checkAppEnabled('files_encryption');
@@ -42,7 +43,7 @@ $recoveryKeyId = \OC::$server->getAppConfig()->getValue('files_encryption', 'rec
 
 if (isset($_POST['adminEnableRecovery']) && $_POST['adminEnableRecovery'] === '1') {
 
-	$return = \OCA\Encryption\Helper::adminEnableRecovery($recoveryKeyId, $_POST['recoveryPassword']);
+	$return = Helper::adminEnableRecovery($recoveryKeyId, $_POST['recoveryPassword']);
 
 	// Return success or failure
 	if ($return) {
@@ -56,7 +57,7 @@ if (isset($_POST['adminEnableRecovery']) && $_POST['adminEnableRecovery'] === '1
 	isset($_POST['adminEnableRecovery'])
 	&& '0' === $_POST['adminEnableRecovery']
 ) {
-	$return = \OCA\Encryption\Helper::adminDisableRecovery($_POST['recoveryPassword']);
+	$return = Helper::adminDisableRecovery($_POST['recoveryPassword']);
 
 	if ($return) {
 		$successMessage = $l->t('Recovery key successfully disabled');
diff --git a/apps/files_encryption/ajax/changeRecoveryPassword.php b/apps/files_encryption/ajax/changeRecoveryPassword.php
index 01b76a969b619ca6f1b1092467a2258900ca4f0f..3d31b12af7c9d0c36adff7e58a719ba44f8a7d3a 100644
--- a/apps/files_encryption/ajax/changeRecoveryPassword.php
+++ b/apps/files_encryption/ajax/changeRecoveryPassword.php
@@ -9,8 +9,6 @@
  *
  */
 
-use OCA\Encryption;
-
 \OCP\JSON::checkAdminUser();
 \OCP\JSON::checkAppEnabled('files_encryption');
 \OCP\JSON::callCheck();
@@ -49,21 +47,21 @@ if ($_POST['newPassword'] !== $_POST['confirmPassword']) {
 }
 
 $view = new \OC\Files\View('/');
-$util = new \OCA\Encryption\Util(new \OC\Files\View('/'), \OCP\User::getUser());
+$util = new \OCA\Files_Encryption\Util(new \OC\Files\View('/'), \OCP\User::getUser());
 
 $proxyStatus = \OC_FileProxy::$enabled;
 \OC_FileProxy::$enabled = false;
 
 $keyId = $util->getRecoveryKeyId();
 
-$encryptedRecoveryKey = Encryption\Keymanager::getPrivateSystemKey($keyId);
-$decryptedRecoveryKey = $encryptedRecoveryKey ? \OCA\Encryption\Crypt::decryptPrivateKey($encryptedRecoveryKey, $oldPassword) : false;
+$encryptedRecoveryKey = \OCA\Files_Encryption\Keymanager::getPrivateSystemKey($keyId);
+$decryptedRecoveryKey = $encryptedRecoveryKey ? \OCA\Files_Encryption\Crypt::decryptPrivateKey($encryptedRecoveryKey, $oldPassword) : false;
 
 if ($decryptedRecoveryKey) {
-	$cipher = \OCA\Encryption\Helper::getCipher();
-	$encryptedKey = \OCA\Encryption\Crypt::symmetricEncryptFileContent($decryptedRecoveryKey, $newPassword, $cipher);
+	$cipher = \OCA\Files_Encryption\Helper::getCipher();
+	$encryptedKey = \OCA\Files_Encryption\Crypt::symmetricEncryptFileContent($decryptedRecoveryKey, $newPassword, $cipher);
 	if ($encryptedKey) {
-		\OCA\Encryption\Keymanager::setPrivateSystemKey($encryptedKey, $keyId);
+		\OCA\Files_Encryption\Keymanager::setPrivateSystemKey($encryptedKey, $keyId);
 		$return = true;
 	}
 }
diff --git a/apps/files_encryption/ajax/getMigrationStatus.php b/apps/files_encryption/ajax/getMigrationStatus.php
index adceb949044efafab7fb346775924c841d9168f7..bb260199b199bdc359cdeb0c38f5dd70d0dea7cb 100644
--- a/apps/files_encryption/ajax/getMigrationStatus.php
+++ b/apps/files_encryption/ajax/getMigrationStatus.php
@@ -6,7 +6,8 @@
  *
  * check migration status
  */
-use OCA\Encryption\Util;
+
+use OCA\Files_Encryption\Util;
 
 \OCP\JSON::checkAppEnabled('files_encryption');
 
diff --git a/apps/files_encryption/ajax/updatePrivateKeyPassword.php b/apps/files_encryption/ajax/updatePrivateKeyPassword.php
index 97da3811a0ffb663ca0cc0684f919efc5dcaf5d5..7161b0cff9223150ed5087d4a15fee49d322b443 100644
--- a/apps/files_encryption/ajax/updatePrivateKeyPassword.php
+++ b/apps/files_encryption/ajax/updatePrivateKeyPassword.php
@@ -9,8 +9,6 @@
  *
  */
 
-use OCA\Encryption;
-
 \OCP\JSON::checkLoggedIn();
 \OCP\JSON::checkAppEnabled('files_encryption');
 \OCP\JSON::callCheck();
@@ -24,7 +22,7 @@ $oldPassword = $_POST['oldPassword'];
 $newPassword = $_POST['newPassword'];
 
 $view = new \OC\Files\View('/');
-$session = new \OCA\Encryption\Session($view);
+$session = new \OCA\Files_Encryption\Session($view);
 $user = \OCP\User::getUser();
 $loginName = \OC::$server->getUserSession()->getLoginName();
 
@@ -36,14 +34,14 @@ if ($passwordCorrect !== false) {
 $proxyStatus = \OC_FileProxy::$enabled;
 \OC_FileProxy::$enabled = false;
 
-$encryptedKey = Encryption\Keymanager::getPrivateKey($view, $user);
-$decryptedKey = $encryptedKey ? \OCA\Encryption\Crypt::decryptPrivateKey($encryptedKey, $oldPassword) : false;
+$encryptedKey = \OCA\Files_Encryption\Keymanager::getPrivateKey($view, $user);
+$decryptedKey = $encryptedKey ? \OCA\Files_Encryption\Crypt::decryptPrivateKey($encryptedKey, $oldPassword) : false;
 
 if ($decryptedKey) {
-	$cipher = \OCA\Encryption\Helper::getCipher();
-	$encryptedKey = \OCA\Encryption\Crypt::symmetricEncryptFileContent($decryptedKey, $newPassword, $cipher);
+	$cipher = \OCA\Files_Encryption\Helper::getCipher();
+	$encryptedKey = \OCA\Files_Encryption\Crypt::symmetricEncryptFileContent($decryptedKey, $newPassword, $cipher);
 	if ($encryptedKey) {
-		\OCA\Encryption\Keymanager::setPrivateKey($encryptedKey, $user);
+		\OCA\Files_Encryption\Keymanager::setPrivateKey($encryptedKey, $user);
 		$session->setPrivateKey($decryptedKey);
 		$return = true;
 	}
@@ -61,7 +59,7 @@ if ($decryptedKey) {
 
 // success or failure
 if ($return) {
-	$session->setInitialized(\OCA\Encryption\Session::INIT_SUCCESSFUL);
+	$session->setInitialized(\OCA\Files_Encryption\Session::INIT_SUCCESSFUL);
 	\OCP\JSON::success(array('data' => array('message' => $l->t('Private key password successfully updated.'))));
 } else {
 	\OCP\JSON::error(array('data' => array('message' => $errorMessage)));
diff --git a/apps/files_encryption/ajax/userrecovery.php b/apps/files_encryption/ajax/userrecovery.php
index a5b89fa723394d1c82934e5efa56cefd3859c5b9..e49fee83a365ff59348b0708287647723fa7d5b7 100644
--- a/apps/files_encryption/ajax/userrecovery.php
+++ b/apps/files_encryption/ajax/userrecovery.php
@@ -7,8 +7,6 @@
  * Script to handle admin settings for encrypted key recovery
  */
 
-use OCA\Encryption;
-
 \OCP\JSON::checkLoggedIn();
 \OCP\JSON::checkAppEnabled('files_encryption');
 \OCP\JSON::callCheck();
@@ -22,7 +20,7 @@ if (
 
 	$userId = \OCP\USER::getUser();
 	$view = new \OC\Files\View('/');
-	$util = new \OCA\Encryption\Util($view, $userId);
+	$util = new \OCA\Files_Encryption\Util($view, $userId);
 
 	// Save recovery preference to DB
 	$return = $util->setRecoveryForUser($_POST['userEnableRecovery']);
diff --git a/apps/files_encryption/appinfo/app.php b/apps/files_encryption/appinfo/app.php
index 7e7e6a5c85992685e0581cff4480587c2dcb8544..f2dc63c340d6bd695371648c850c7d16502dd05c 100644
--- a/apps/files_encryption/appinfo/app.php
+++ b/apps/files_encryption/appinfo/app.php
@@ -5,22 +5,22 @@
 \OCP\Util::addscript('files_encryption', 'detect-migration');
 
 if (!OC_Config::getValue('maintenance', false)) {
-	OC_FileProxy::register(new OCA\Encryption\Proxy());
+	OC_FileProxy::register(new OCA\Files_Encryption\Proxy());
 
 	// User related hooks
-	OCA\Encryption\Helper::registerUserHooks();
+	OCA\Files_Encryption\Helper::registerUserHooks();
 
 	// Sharing related hooks
-	OCA\Encryption\Helper::registerShareHooks();
+	OCA\Files_Encryption\Helper::registerShareHooks();
 
 	// Filesystem related hooks
-	OCA\Encryption\Helper::registerFilesystemHooks();
+	OCA\Files_Encryption\Helper::registerFilesystemHooks();
 
 	// App manager related hooks
-	OCA\Encryption\Helper::registerAppHooks();
+	OCA\Files_Encryption\Helper::registerAppHooks();
 
 	if(!in_array('crypt', stream_get_wrappers())) {
-		stream_wrapper_register('crypt', 'OCA\Encryption\Stream');
+		stream_wrapper_register('crypt', 'OCA\Files_Encryption\Stream');
 	}
 } else {
 	// logout user if we are in maintenance to force re-login
diff --git a/apps/files_encryption/appinfo/routes.php b/apps/files_encryption/appinfo/routes.php
index 97635ae1236b93f7740cb28323a44d588c1f101e..9733c17fe95db5a09ea6ff501790ce2c1f068869 100644
--- a/apps/files_encryption/appinfo/routes.php
+++ b/apps/files_encryption/appinfo/routes.php
@@ -19,4 +19,4 @@ $this->create('files_encryption_ajax_userrecovery', 'ajax/userrecovery.php')
 	->actionInclude('files_encryption/ajax/userrecovery.php');
 
 // Register with the capabilities API
-OC_API::register('get', '/cloud/capabilities', array('OCA\Encryption\Capabilities', 'getCapabilities'), 'files_encryption', OC_API::USER_AUTH);
+OC_API::register('get', '/cloud/capabilities', array('OCA\Files_Encryption\Capabilities', 'getCapabilities'), 'files_encryption', OC_API::USER_AUTH);
diff --git a/apps/files_encryption/files/error.php b/apps/files_encryption/files/error.php
index b801c17bd402ab9f7a1aa89a93b5879caf5b1f85..4a1ed021f7c3c7308c64a0ecff626b859f8fe8e2 100644
--- a/apps/files_encryption/files/error.php
+++ b/apps/files_encryption/files/error.php
@@ -12,14 +12,14 @@ if (!isset($_)) { //also provide standalone error page
 	if (isset($_GET['errorCode'])) {
 		$errorCode = $_GET['errorCode'];
 		switch ($errorCode) {
-			case \OCA\Encryption\Crypt::ENCRYPTION_NOT_INITIALIZED_ERROR:
+			case \OCA\Files_Encryption\Crypt::ENCRYPTION_NOT_INITIALIZED_ERROR:
 				$errorMsg = $l->t('Encryption app not initialized! Maybe the encryption app was re-enabled during your session. Please try to log out and log back in to initialize the encryption app.');
 				break;
-			case \OCA\Encryption\Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR:
+			case \OCA\Files_Encryption\Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR:
 				$theme = new OC_Defaults();
 				$errorMsg = $l->t('Your private key is not valid! Likely your password was changed outside of %s (e.g. your corporate directory). You can update your private key password in your personal settings to recover access to your encrypted files.', array($theme->getName()));
 				break;
-			case \OCA\Encryption\Crypt::ENCRYPTION_NO_SHARE_KEY_FOUND:
+			case \OCA\Files_Encryption\Crypt::ENCRYPTION_NO_SHARE_KEY_FOUND:
 				$errorMsg = $l->t('Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you.');
 				break;
 			default:
@@ -27,7 +27,7 @@ if (!isset($_)) { //also provide standalone error page
 				break;
 		}
 	} else {
-		$errorCode = \OCA\Encryption\Crypt::ENCRYPTION_UNKNOWN_ERROR;
+		$errorCode = \OCA\Files_Encryption\Crypt::ENCRYPTION_UNKNOWN_ERROR;
 		$errorMsg = $l->t("Unknown error. Please check your system settings or contact your administrator");
 	}
 
diff --git a/apps/files_encryption/lib/crypt.php b/apps/files_encryption/lib/crypt.php
index 34b676dba2c9dc938609e7668e4ff5429b2c55e1..38993ba65b0a8f6792b8c74f69018f5242da4834 100644
--- a/apps/files_encryption/lib/crypt.php
+++ b/apps/files_encryption/lib/crypt.php
@@ -133,7 +133,7 @@ class Crypt {
 	 * Check if a file's contents contains an IV and is symmetrically encrypted
 	 * @param string $content
 	 * @return boolean
-	 * @note see also OCA\Encryption\Util->isEncryptedPath()
+	 * @note see also \OCA\Files_Encryption\Util->isEncryptedPath()
 	 */
 	public static function isCatfileContent($content) {
 
@@ -190,7 +190,7 @@ class Crypt {
 	 * @param string $passphrase
 	 * @param string $cypher used for encryption, currently we support AES-128-CFB and AES-256-CFB
 	 * @return string encrypted file content
-	 * @throws \OCA\Encryption\Exception\EncryptionException
+	 * @throws \OCA\Files_Encryption\Exception\EncryptionException
 	 */
 	private static function encrypt($plainContent, $iv, $passphrase = '', $cipher = Crypt::DEFAULT_CIPHER) {
 
@@ -379,7 +379,7 @@ class Crypt {
 	 * @param string $plainContent content to be encrypted
 	 * @param array $publicKeys array keys must be the userId of corresponding user
 	 * @return array keys: keys (array, key = userId), data
-	 * @throws \OCA\Encryption\Exception\MultiKeyEncryptException if encryption failed
+	 * @throws \OCA\Files_Encryption\Exception\MultiKeyEncryptException if encryption failed
 	 * @note symmetricDecryptFileContent() can decrypt files created using this method
 	 */
 	public static function multiKeyEncrypt($plainContent, array $publicKeys) {
@@ -425,7 +425,7 @@ class Crypt {
 	 * @param string $encryptedContent
 	 * @param string $shareKey
 	 * @param mixed $privateKey
-	 * @throws \OCA\Encryption\Exception\MultiKeyDecryptException if decryption failed
+	 * @throws \OCA\Files_Encryption\Exception\MultiKeyDecryptException if decryption failed
 	 * @internal param string $plainContent contains decrypted content
 	 * @return string $plainContent decrypted string
 	 * @note symmetricDecryptFileContent() can be used to decrypt files created using this method
@@ -554,7 +554,7 @@ class Crypt {
 	 * get chiper from header
 	 *
 	 * @param array $header
-	 * @throws \OCA\Encryption\Exception\EncryptionException
+	 * @throws \OCA\Files_Encryption\Exception\EncryptionException
 	 */
 	public static function getCipher($header) {
 		$cipher = isset($header['cipher']) ? $header['cipher'] : 'AES-128-CFB';
diff --git a/apps/files_encryption/lib/helper.php b/apps/files_encryption/lib/helper.php
index b1147a0eb52a15373a2d70b7308dd3aaec3c80f8..6a8ea25d44eb96b30e49c2b2865653ebd7c0f824 100644
--- a/apps/files_encryption/lib/helper.php
+++ b/apps/files_encryption/lib/helper.php
@@ -27,7 +27,7 @@ namespace OCA\Files_Encryption;
 
 /**
  * Class to manage registration of hooks an various helper methods
- * @package OCA\Encryption
+ * @package OCA\Files_Encryption
  */
 class Helper {
 
@@ -39,9 +39,9 @@ class Helper {
 	 */
 	public static function registerShareHooks() {
 
-		\OCP\Util::connectHook('OCP\Share', 'pre_shared', 'OCA\Encryption\Hooks', 'preShared');
-		\OCP\Util::connectHook('OCP\Share', 'post_shared', 'OCA\Encryption\Hooks', 'postShared');
-		\OCP\Util::connectHook('OCP\Share', 'post_unshare', 'OCA\Encryption\Hooks', 'postUnshare');
+		\OCP\Util::connectHook('OCP\Share', 'pre_shared', 'OCA\Files_Encryption\Hooks', 'preShared');
+		\OCP\Util::connectHook('OCP\Share', 'post_shared', 'OCA\Files_Encryption\Hooks', 'postShared');
+		\OCP\Util::connectHook('OCP\Share', 'post_unshare', 'OCA\Files_Encryption\Hooks', 'postUnshare');
 	}
 
 	/**
@@ -50,12 +50,12 @@ class Helper {
 	 */
 	public static function registerUserHooks() {
 
-		\OCP\Util::connectHook('OC_User', 'post_login', 'OCA\Encryption\Hooks', 'login');
-		\OCP\Util::connectHook('OC_User', 'logout', 'OCA\Encryption\Hooks', 'logout');
-		\OCP\Util::connectHook('OC_User', 'post_setPassword', 'OCA\Encryption\Hooks', 'setPassphrase');
-		\OCP\Util::connectHook('OC_User', 'pre_setPassword', 'OCA\Encryption\Hooks', 'preSetPassphrase');
-		\OCP\Util::connectHook('OC_User', 'post_createUser', 'OCA\Encryption\Hooks', 'postCreateUser');
-		\OCP\Util::connectHook('OC_User', 'post_deleteUser', 'OCA\Encryption\Hooks', 'postDeleteUser');
+		\OCP\Util::connectHook('OC_User', 'post_login', 'OCA\Files_Encryption\Hooks', 'login');
+		\OCP\Util::connectHook('OC_User', 'logout', 'OCA\Files_Encryption\Hooks', 'logout');
+		\OCP\Util::connectHook('OC_User', 'post_setPassword', 'OCA\Files_Encryption\Hooks', 'setPassphrase');
+		\OCP\Util::connectHook('OC_User', 'pre_setPassword', 'OCA\Files_Encryption\Hooks', 'preSetPassphrase');
+		\OCP\Util::connectHook('OC_User', 'post_createUser', 'OCA\Files_Encryption\Hooks', 'postCreateUser');
+		\OCP\Util::connectHook('OC_User', 'post_deleteUser', 'OCA\Files_Encryption\Hooks', 'postDeleteUser');
 	}
 
 	/**
@@ -64,15 +64,15 @@ class Helper {
 	 */
 	public static function registerFilesystemHooks() {
 
-		\OCP\Util::connectHook('OC_Filesystem', 'rename', 'OCA\Encryption\Hooks', 'preRename');
-		\OCP\Util::connectHook('OC_Filesystem', 'post_rename', 'OCA\Encryption\Hooks', 'postRenameOrCopy');
-		\OCP\Util::connectHook('OC_Filesystem', 'copy', 'OCA\Encryption\Hooks', 'preCopy');
-		\OCP\Util::connectHook('OC_Filesystem', 'post_copy', 'OCA\Encryption\Hooks', 'postRenameOrCopy');
-		\OCP\Util::connectHook('OC_Filesystem', 'post_delete', 'OCA\Encryption\Hooks', 'postDelete');
-		\OCP\Util::connectHook('OC_Filesystem', 'delete', 'OCA\Encryption\Hooks', 'preDelete');
-		\OCP\Util::connectHook('\OC\Core\LostPassword\Controller\LostController', 'post_passwordReset', 'OCA\Encryption\Hooks', 'postPasswordReset');
-		\OCP\Util::connectHook('OC_Filesystem', 'post_umount', 'OCA\Encryption\Hooks', 'postUnmount');
-		\OCP\Util::connectHook('OC_Filesystem', 'umount', 'OCA\Encryption\Hooks', 'preUnmount');
+		\OCP\Util::connectHook('OC_Filesystem', 'rename', 'OCA\Files_Encryption\Hooks', 'preRename');
+		\OCP\Util::connectHook('OC_Filesystem', 'post_rename', 'OCA\Files_Encryption\Hooks', 'postRenameOrCopy');
+		\OCP\Util::connectHook('OC_Filesystem', 'copy', 'OCA\Files_Encryption\Hooks', 'preCopy');
+		\OCP\Util::connectHook('OC_Filesystem', 'post_copy', 'OCA\Files_Encryption\Hooks', 'postRenameOrCopy');
+		\OCP\Util::connectHook('OC_Filesystem', 'post_delete', 'OCA\Files_Encryption\Hooks', 'postDelete');
+		\OCP\Util::connectHook('OC_Filesystem', 'delete', 'OCA\Files_Encryption\Hooks', 'preDelete');
+		\OCP\Util::connectHook('\OC\Core\LostPassword\Controller\LostController', 'post_passwordReset', 'OCA\Files_Encryption\Hooks', 'postPasswordReset');
+		\OCP\Util::connectHook('OC_Filesystem', 'post_umount', 'OCA\Files_Encryption\Hooks', 'postUnmount');
+		\OCP\Util::connectHook('OC_Filesystem', 'umount', 'OCA\Files_Encryption\Hooks', 'preUnmount');
 	}
 
 	/**
@@ -81,8 +81,8 @@ class Helper {
 	 */
 	public static function registerAppHooks() {
 
-		\OCP\Util::connectHook('OC_App', 'pre_disable', 'OCA\Encryption\Hooks', 'preDisable');
-		\OCP\Util::connectHook('OC_App', 'post_disable', 'OCA\Encryption\Hooks', 'postEnable');
+		\OCP\Util::connectHook('OC_App', 'pre_disable', 'OCA\Files_Encryption\Hooks', 'preDisable');
+		\OCP\Util::connectHook('OC_App', 'post_disable', 'OCA\Files_Encryption\Hooks', 'postEnable');
 	}
 
 	/**
@@ -131,8 +131,6 @@ class Helper {
 	 *
 	 * @param string $recoveryKeyId
 	 * @param string $recoveryPassword
-	 * @internal param \OCA\Encryption\Util $util
-	 * @internal param string $password
 	 * @return bool
 	 */
 	public static function adminEnableRecovery($recoveryKeyId, $recoveryPassword) {
@@ -147,13 +145,13 @@ class Helper {
 
 		if (!Keymanager::recoveryKeyExists($view)) {
 
-			$keypair = \OCA\Encryption\Crypt::createKeypair();
+			$keypair = Crypt::createKeypair();
 
 			// Save public key
 			Keymanager::setPublicKey($keypair['publicKey'], $recoveryKeyId);
 
-			$cipher = \OCA\Encryption\Helper::getCipher();
-			$encryptedKey = \OCA\Encryption\Crypt::symmetricEncryptFileContent($keypair['privateKey'], $recoveryPassword, $cipher);
+			$cipher = Helper::getCipher();
+			$encryptedKey = Crypt::symmetricEncryptFileContent($keypair['privateKey'], $recoveryPassword, $cipher);
 			if ($encryptedKey) {
 				Keymanager::setPrivateSystemKey($encryptedKey, $recoveryKeyId);
 				// Set recoveryAdmin as enabled
@@ -162,7 +160,7 @@ class Helper {
 			}
 
 		} else { // get recovery key and check the password
-			$util = new \OCA\Encryption\Util(new \OC\Files\View('/'), \OCP\User::getUser());
+			$util = new Util(new \OC\Files\View('/'), \OCP\User::getUser());
 			$return = $util->checkRecoveryPassword($recoveryPassword);
 			if ($return) {
 				$appConfig->setValue('files_encryption', 'recoveryAdminEnabled', 1);
@@ -362,14 +360,14 @@ class Helper {
 		if ($errorCode === null) {
 			$init = $session->getInitialized();
 			switch ($init) {
-				case \OCA\Encryption\Session::INIT_EXECUTED:
-					$errorCode = \OCA\Encryption\Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR;
+				case Session::INIT_EXECUTED:
+					$errorCode = Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR;
 					break;
-				case \OCA\Encryption\Session::NOT_INITIALIZED:
-					$errorCode = \OCA\Encryption\Crypt::ENCRYPTION_NOT_INITIALIZED_ERROR;
+				case Session::NOT_INITIALIZED:
+					$errorCode = Crypt::ENCRYPTION_NOT_INITIALIZED_ERROR;
 					break;
 				default:
-					$errorCode = \OCA\Encryption\Crypt::ENCRYPTION_UNKNOWN_ERROR;
+					$errorCode = Crypt::ENCRYPTION_UNKNOWN_ERROR;
 			}
 		}
 
diff --git a/apps/files_encryption/lib/hooks.php b/apps/files_encryption/lib/hooks.php
index a22477fce9e001ca07cff58d96ce64466ce15a26..bddfb7b2544583158fca01be6c6578114a6a73c6 100644
--- a/apps/files_encryption/lib/hooks.php
+++ b/apps/files_encryption/lib/hooks.php
@@ -59,7 +59,7 @@ class Hooks {
 			\OC_Util::setupFS($params['uid']);
 		}
 
-		$privateKey = \OCA\Encryption\Keymanager::getPrivateKey($view, $params['uid']);
+		$privateKey = Keymanager::getPrivateKey($view, $params['uid']);
 
 		// if no private key exists, check server configuration
 		if (!$privateKey) {
@@ -128,7 +128,7 @@ class Hooks {
 	 * remove keys from session during logout
 	 */
 	public static function logout() {
-		$session = new \OCA\Encryption\Session(new \OC\Files\View());
+		$session = new Session(new \OC\Files\View());
 		$session->removeKeys();
 	}
 
@@ -182,7 +182,7 @@ class Hooks {
 		if (Crypt::mode() === 'server') {
 
 			$view = new \OC\Files\View('/');
-			$session = new \OCA\Encryption\Session($view);
+			$session = new Session($view);
 
 			// Get existing decrypted private key
 			$privateKey = $session->getPrivateKey();
@@ -236,7 +236,7 @@ class Hooks {
 					Keymanager::setPublicKey($keypair['publicKey'], $user);
 
 					// Encrypt private key with new password
-					$encryptedKey = \OCA\Encryption\Crypt::symmetricEncryptFileContent($keypair['privateKey'], $newUserPassword, Helper::getCipher());
+					$encryptedKey = Crypt::symmetricEncryptFileContent($keypair['privateKey'], $newUserPassword, Helper::getCipher());
 					if ($encryptedKey) {
 						Keymanager::setPrivateKey($encryptedKey, $user);
 
@@ -331,7 +331,7 @@ class Hooks {
 	private static function updateKeyfiles($path) {
 		$view = new \OC\Files\View('/');
 		$userId = \OCP\User::getUser();
-		$session = new \OCA\Encryption\Session($view);
+		$session = new Session($view);
 		$util = new Util($view, $userId);
 		$sharingEnabled = \OCP\Share::isEnabled();
 
@@ -504,8 +504,8 @@ class Hooks {
 
 			\OC::$server->getConfig()->deleteAppFromAllUsers('files_encryption');
 
-			$session = new \OCA\Encryption\Session(new \OC\Files\View('/'));
-			$session->setInitialized(\OCA\Encryption\Session::NOT_INITIALIZED);
+			$session = new Session(new \OC\Files\View('/'));
+			$session->setInitialized(Session::NOT_INITIALIZED);
 		}
 	}
 
@@ -515,8 +515,8 @@ class Hooks {
 	 */
 	public static function postEnable($params) {
 		if ($params['app'] === 'files_encryption') {
-			$session = new \OCA\Encryption\Session(new \OC\Files\View('/'));
-			$session->setInitialized(\OCA\Encryption\Session::NOT_INITIALIZED);
+			$session = new Session(new \OC\Files\View('/'));
+			$session->setInitialized(Session::NOT_INITIALIZED);
 		}
 	}
 
diff --git a/apps/files_encryption/lib/keymanager.php b/apps/files_encryption/lib/keymanager.php
index 16f0610f01f9aa6d122b8e9f2683fee0e72aacee..dfde3684798d50c86beb51448a4b484602da022b 100644
--- a/apps/files_encryption/lib/keymanager.php
+++ b/apps/files_encryption/lib/keymanager.php
@@ -141,7 +141,7 @@ class Keymanager {
 	 * store file encryption key
 	 *
 	 * @param \OC\Files\View $view
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $path relative path of the file, including filename
 	 * @param string $catfile keyfile content
 	 * @return bool true/false
@@ -158,7 +158,7 @@ class Keymanager {
 	 * get path to key folder for a given file
 	 *
 	 * @param \OC\Files\View $view relative to data directory
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $path path to the file, relative to the users file directory
 	 * @return string
 	 */
@@ -186,7 +186,7 @@ class Keymanager {
 	 * get path to file key for a given file
 	 *
 	 * @param \OC\Files\View $view relative to data directory
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $path path to the file, relative to the users file directory
 	 * @return string
 	 */
@@ -199,7 +199,7 @@ class Keymanager {
 	 * get path to share key for a given user
 	 *
 	 * @param \OC\Files\View $view relateive to data directory
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $path path to file relative to the users files directoy
 	 * @param string $uid user for whom we want the share-key path
 	 * @retrun string
@@ -243,9 +243,8 @@ class Keymanager {
 	/**
 	 * retrieve keyfile for an encrypted file
 	 * @param \OC\Files\View $view
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string|false $filePath
-	 * @internal param \OCA\Encryption\file $string name
 	 * @return string file key or false
 	 * @note The keyfile returned is asymmetrically encrypted. Decryption
 	 * of the keyfile must be performed by client code
@@ -347,7 +346,7 @@ class Keymanager {
 	/**
 	 * store multiple share keys for a single file
 	 * @param \OC\Files\View $view
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $path
 	 * @param array $shareKeys
 	 * @return bool
@@ -376,7 +375,7 @@ class Keymanager {
 	 * retrieve shareKey for an encrypted file
 	 * @param \OC\Files\View $view
 	 * @param string $userId
-	 * @param \OCA\Encryption\Util $util
+	 * @param \OCA\Files_Encryption\Util $util
 	 * @param string $filePath
 	 * @return string file key or false
 	 * @note The sharekey returned is encrypted. Decryption
diff --git a/apps/files_encryption/lib/migration.php b/apps/files_encryption/lib/migration.php
index ee2e52114cfd5dc1bd1dab09c2cce3a528f4d00c..1bab1dfe4a5716f9d9d31bfaa0a8c999a5f6e1ad 100644
--- a/apps/files_encryption/lib/migration.php
+++ b/apps/files_encryption/lib/migration.php
@@ -35,8 +35,8 @@ class Migration {
 
 	public function __construct() {
 		$this->view = new \OC\Files\View();
-		$this->public_share_key_id = \OCA\Encryption\Helper::getPublicShareKeyId();
-		$this->recovery_key_id = \OCA\Encryption\Helper::getRecoveryKeyId();
+		$this->public_share_key_id = Helper::getPublicShareKeyId();
+		$this->recovery_key_id = Helper::getRecoveryKeyId();
 	}
 
 	public function reorganizeFolderStructure() {
diff --git a/apps/files_encryption/lib/proxy.php b/apps/files_encryption/lib/proxy.php
index 720b88c3d717579d9cc0086668db0f8fcd5e7b96..ba78c81aa35149b9ef94ec097f88ae8bd6b1e03d 100644
--- a/apps/files_encryption/lib/proxy.php
+++ b/apps/files_encryption/lib/proxy.php
@@ -34,7 +34,7 @@ namespace OCA\Files_Encryption;
 
 /**
  * Class Proxy
- * @package OCA\Encryption
+ * @package OCA\Files_Encryption
  */
 class Proxy extends \OC_FileProxy {
 
@@ -130,7 +130,7 @@ class Proxy extends \OC_FileProxy {
 				$view = new \OC\Files\View('/');
 
 				// get relative path
-				$relativePath = \OCA\Encryption\Helper::stripUserFilesPath($path);
+				$relativePath = Helper::stripUserFilesPath($path);
 
 				if (!isset($relativePath)) {
 					return true;
@@ -338,7 +338,7 @@ class Proxy extends \OC_FileProxy {
 		}
 
 		// get relative path
-		$relativePath = \OCA\Encryption\Helper::stripUserFilesPath($path);
+		$relativePath = Helper::stripUserFilesPath($path);
 
 		// if path is empty we cannot resolve anything
 		if (empty($relativePath)) {
diff --git a/apps/files_encryption/lib/session.php b/apps/files_encryption/lib/session.php
index e84befb6edea8d80268b4a378e690c58fab4ddf7..4c70bc7e8fcc9706e16607e713413b5414baa36a 100644
--- a/apps/files_encryption/lib/session.php
+++ b/apps/files_encryption/lib/session.php
@@ -72,8 +72,8 @@ class Session {
 			Keymanager::setPublicKey($keypair['publicKey'], $publicShareKeyId);
 
 			// Encrypt private key empty passphrase
-			$cipher = \OCA\Encryption\Helper::getCipher();
-			$encryptedKey = \OCA\Encryption\Crypt::symmetricEncryptFileContent($keypair['privateKey'], '', $cipher);
+			$cipher = Helper::getCipher();
+			$encryptedKey = Crypt::symmetricEncryptFileContent($keypair['privateKey'], '', $cipher);
 			if ($encryptedKey) {
 				Keymanager::setPrivateSystemKey($encryptedKey, $publicShareKeyId);
 			} else {
@@ -82,7 +82,7 @@ class Session {
 
 		}
 
-		if (\OCA\Encryption\Helper::isPublicAccess() && !self::getPublicSharePrivateKey()) {
+		if (Helper::isPublicAccess() && !self::getPublicSharePrivateKey()) {
 			// Disable encryption proxy to prevent recursive calls
 			$proxyStatus = \OC_FileProxy::$enabled;
 			\OC_FileProxy::$enabled = false;
@@ -151,7 +151,7 @@ class Session {
 	public function getInitialized() {
 		if (!is_null(\OC::$server->getSession()->get('encryptionInitialized'))) {
 			return \OC::$server->getSession()->get('encryptionInitialized');
-		} else if (\OCA\Encryption\Helper::isPublicAccess() && self::getPublicSharePrivateKey()) {
+		} else if (Helper::isPublicAccess() && self::getPublicSharePrivateKey()) {
 			return self::INIT_SUCCESSFUL;
 		} else {
 			return self::NOT_INITIALIZED;
@@ -165,7 +165,7 @@ class Session {
 	 */
 	public function getPrivateKey() {
 		// return the public share private key if this is a public access
-		if (\OCA\Encryption\Helper::isPublicAccess()) {
+		if (Helper::isPublicAccess()) {
 			return self::getPublicSharePrivateKey();
 		} else {
 			if (!is_null(\OC::$server->getSession()->get('privateKey'))) {
diff --git a/apps/files_encryption/lib/stream.php b/apps/files_encryption/lib/stream.php
index 430bdb595b4fa7ffd3ac5e0722f361385194f508..17da4eb1cdc20c78f15e5ca2358bdb61d617e0e3 100644
--- a/apps/files_encryption/lib/stream.php
+++ b/apps/files_encryption/lib/stream.php
@@ -31,7 +31,8 @@
  */
 
 namespace OCA\Files_Encryption;
-use OCA\Encryption\Exception\EncryptionException;
+
+use OCA\Files_Encryption\Exception\EncryptionException;
 
 /**
  * Provides 'crypt://' stream wrapper protocol.
@@ -81,7 +82,7 @@ class Stream {
 	private $rootView; // a fsview object set to '/'
 
 	/**
-	 * @var \OCA\Encryption\Session
+	 * @var \OCA\Files_Encryption\Session
 	 */
 	private $session;
 	private $privateKey;
@@ -92,7 +93,7 @@ class Stream {
 	 * @param int $options
 	 * @param string $opened_path
 	 * @return bool
-	 * @throw \OCA\Encryption\Exception\EncryptionException
+	 * @throw \OCA\Files_Encryption\Exception\EncryptionException
 	 */
 	public function stream_open($path, $mode, $options, &$opened_path) {
 
@@ -106,7 +107,7 @@ class Stream {
 			$this->rootView = new \OC\Files\View('/');
 		}
 
-		$this->session = new \OCA\Encryption\Session($this->rootView);
+		$this->session = new Session($this->rootView);
 
 		$this->privateKey = $this->session->getPrivateKey();
 		if ($this->privateKey === false) {
@@ -162,7 +163,7 @@ class Stream {
 
 			if($this->privateKey === false) {
 				// if private key is not valid redirect user to a error page
-				\OCA\Encryption\Helper::redirectToErrorPage($this->session);
+				Helper::redirectToErrorPage($this->session);
 			}
 
 			$this->size = $this->rootView->filesize($this->rawPath);
@@ -251,7 +252,7 @@ class Stream {
 	/**
 	 * @param int $count
 	 * @return bool|string
-	 * @throws \OCA\Encryption\Exception\EncryptionException
+	 * @throws \OCA\Files_Encryption\Exception\EncryptionException
 	 */
 	public function stream_read($count) {
 
@@ -329,7 +330,7 @@ class Stream {
 
 		// Fetch and decrypt keyfile
 		// Fetch existing keyfile
-		$util = new \OCA\Encryption\Util($this->rootView, $this->userId);
+		$util = new Util($this->rootView, $this->userId);
 		$this->encKeyfile = Keymanager::getFileKey($this->rootView, $util, $this->relPath);
 
 		// If a keyfile already exists
@@ -340,13 +341,13 @@ class Stream {
 			// if there is no valid private key return false
 			if ($this->privateKey === false) {
 				// if private key is not valid redirect user to a error page
-				\OCA\Encryption\Helper::redirectToErrorPage($this->session);
+				Helper::redirectToErrorPage($this->session);
 				return false;
 			}
 
 			if ($shareKey === false) {
 				// if no share key is available redirect user to a error page
-				\OCA\Encryption\Helper::redirectToErrorPage($this->session, \OCA\Encryption\Crypt::ENCRYPTION_NO_SHARE_KEY_FOUND);
+				Helper::redirectToErrorPage($this->session, Crypt::ENCRYPTION_NO_SHARE_KEY_FOUND);
 				return false;
 			}
 
@@ -367,7 +368,7 @@ class Stream {
 	/**
 	 * write header at beginning of encrypted file
 	 *
-	 * @throws Exception\EncryptionException
+	 * @throws \OCA\Files_Encryption\Exception\EncryptionException
 	 */
 	private function writeHeader() {
 
@@ -589,7 +590,7 @@ class Stream {
 			}
 
 			// if private key is not valid redirect user to a error page
-			\OCA\Encryption\Helper::redirectToErrorPage($this->session);
+			Helper::redirectToErrorPage($this->session);
 		}
 
 		if (
diff --git a/apps/files_encryption/lib/util.php b/apps/files_encryption/lib/util.php
index 2052a976f715ac87f85cd6037f9453350ad86e01..ad6948b95a69b67978341d7355a0e8a3f3c684ca 100644
--- a/apps/files_encryption/lib/util.php
+++ b/apps/files_encryption/lib/util.php
@@ -83,7 +83,7 @@ class Util {
 		// make sure that the owners home is mounted
 		\OC\Files\Filesystem::initMountPoints($userId);
 
-		if (\OCA\Encryption\Helper::isPublicAccess()) {
+		if (Helper::isPublicAccess()) {
 			$this->keyId = $this->publicShareKeyId;
 			$this->isPublic = true;
 		} else {
@@ -277,7 +277,7 @@ class Util {
 					if ($file !== "." && $file !== "..") {
 
 						$filePath = $directory . '/' . $this->view->getRelativePath('/' . $file);
-						$relPath = \OCA\Encryption\Helper::stripUserFilesPath($filePath);
+						$relPath = Helper::stripUserFilesPath($filePath);
 
 						// If the path is a directory, search
 						// its contents
@@ -451,13 +451,13 @@ class Util {
 					}
 				}
 				fclose($stream);
-				$relPath = \OCA\Encryption\Helper::stripUserFilesPath($path);
+				$relPath = Helper::stripUserFilesPath($path);
 				$shareKey = Keymanager::getShareKey($this->view, $this->keyId, $this, $relPath);
 				if($shareKey===false) {
 					\OC_FileProxy::$enabled = $proxyStatus;
 					return $result;
 				}
-				$session = new \OCA\Encryption\Session($this->view);
+				$session = new Session($this->view);
 				$privateKey = $session->getPrivateKey();
 				$plainKeyfile = $this->decryptKeyfile($relPath, $privateKey);
 				$plainKey = Crypt::multiKeyDecrypt($plainKeyfile, $shareKey, $privateKey);
@@ -1040,7 +1040,7 @@ class Util {
 		// Make sure that a share key is generated for the owner too
 		list($owner, $ownerPath) = $this->getUidAndFilename($filePath);
 
-		$ownerPath = \OCA\Encryption\Helper::stripPartialFileExtension($ownerPath);
+		$ownerPath = Helper::stripPartialFileExtension($ownerPath);
 
 		// always add owner to the list of users with access to the file
 		$userIds = array($owner);
@@ -1402,7 +1402,7 @@ class Util {
 			if ($this->view->is_dir($this->userFilesDir . '/' . $filePath)) {
 				$this->addRecoveryKeys($filePath . '/');
 			} else {
-				$session = new \OCA\Encryption\Session(new \OC\Files\View('/'));
+				$session = new Session(new \OC\Files\View('/'));
 				$sharingEnabled = \OCP\Share::isEnabled();
 				$usersSharing = $this->getSharingUsersArray($sharingEnabled, $filePath);
 				$this->setSharedFileKeyfiles($session, $usersSharing, $filePath);
@@ -1559,10 +1559,10 @@ class Util {
 	 */
 	public function initEncryption($params) {
 
-		$session = new \OCA\Encryption\Session($this->view);
+		$session = new Session($this->view);
 
 		// we tried to initialize the encryption app for this session
-		$session->setInitialized(\OCA\Encryption\Session::INIT_EXECUTED);
+		$session->setInitialized(Session::INIT_EXECUTED);
 
 		$encryptedKey = Keymanager::getPrivateKey($this->view, $params['uid']);
 
@@ -1578,7 +1578,7 @@ class Util {
 		}
 
 		$session->setPrivateKey($privateKey);
-		$session->setInitialized(\OCA\Encryption\Session::INIT_SUCCESSFUL);
+		$session->setInitialized(Session::INIT_SUCCESSFUL);
 
 		return $session;
 	}
@@ -1587,7 +1587,7 @@ class Util {
 	 * remove encryption related keys from the session
 	 */
 	public function closeEncryptionSession() {
-		$session = new \OCA\Encryption\Session($this->view);
+		$session = new Session($this->view);
 		$session->closeSession();
 	}
 
diff --git a/apps/files_encryption/settings-admin.php b/apps/files_encryption/settings-admin.php
index 496a7cffb5082d8ad0f1534c87e05c9da19050ba..0f5d56a3734bf596df3e0494b7d8e7b41705060b 100644
--- a/apps/files_encryption/settings-admin.php
+++ b/apps/files_encryption/settings-admin.php
@@ -12,7 +12,7 @@ $tmpl = new OCP\Template('files_encryption', 'settings-admin');
 
 // Check if an adminRecovery account is enabled for recovering files after lost pwd
 $recoveryAdminEnabled = \OC::$server->getAppConfig()->getValue('files_encryption', 'recoveryAdminEnabled', '0');
-$session = new \OCA\Encryption\Session(new \OC\Files\View('/'));
+$session = new \OCA\Files_Encryption\Session(new \OC\Files\View('/'));
 $initStatus = $session->getInitialized();
 
 $tmpl->assign('recoveryEnabled', $recoveryAdminEnabled);
diff --git a/apps/files_encryption/settings-personal.php b/apps/files_encryption/settings-personal.php
index e9875518f67956b3f7227b735bac07eb7d51cbbd..966556f6f9411b989f787becb51717f9ef9a3e7c 100644
--- a/apps/files_encryption/settings-personal.php
+++ b/apps/files_encryption/settings-personal.php
@@ -13,8 +13,8 @@ $tmpl = new OCP\Template('files_encryption', 'settings-personal');
 
 $user = \OCP\USER::getUser();
 $view = new \OC\Files\View('/');
-$util = new \OCA\Encryption\Util($view, $user);
-$session = new \OCA\Encryption\Session($view);
+$util = new \OCA\Files_Encryption\Util($view, $user);
+$session = new \OCA\Files_Encryption\Session($view);
 
 $privateKeySet = $session->getPrivateKey() !== false;
 // did we tried to initialize the keys for this session?
diff --git a/apps/files_encryption/templates/invalid_private_key.php b/apps/files_encryption/templates/invalid_private_key.php
index b275b9c428c8e22aca5073205c94c88f785a453b..b148e65b199b27153645af026eea2b31e547d12e 100644
--- a/apps/files_encryption/templates/invalid_private_key.php
+++ b/apps/files_encryption/templates/invalid_private_key.php
@@ -4,7 +4,7 @@
 
 		<?php p($_['message']); ?>
 		<br/>
-		<?php if($_['errorCode'] === \OCA\Encryption\Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR): ?>
+		<?php if($_['errorCode'] === \OCA\Files_Encryption\Crypt::ENCRYPTION_PRIVATE_KEY_NOT_VALID_ERROR): ?>
 			<?php p($l->t('Go directly to your %spersonal settings%s.', array('<a href="'.$location.'">', '</a>'))); ?>
 		<?php endif; ?>
 		<br/>
diff --git a/apps/files_encryption/templates/settings-admin.php b/apps/files_encryption/templates/settings-admin.php
index d003f245bb33c4abd5d998442bf275acfff08f8c..4c1d724b6ddfd85ea6a1c4455d882f1a0baecd5a 100644
--- a/apps/files_encryption/templates/settings-admin.php
+++ b/apps/files_encryption/templates/settings-admin.php
@@ -1,7 +1,7 @@
 <form id="encryption" class="section">
 	<h2><?php p($l->t('Encryption')); ?></h2>
 
-	<?php if($_["initStatus"] === \OCA\Encryption\Session::NOT_INITIALIZED): ?>
+	<?php if($_["initStatus"] === \OCA\Files_Encryption\Session::NOT_INITIALIZED): ?>
 		<?php p($l->t("Encryption App is enabled but your keys are not initialized, please log-out and log-in again")); ?>
 	<?php else: ?>
 	<p id="encryptionSetRecoveryKey">
diff --git a/apps/files_encryption/templates/settings-personal.php b/apps/files_encryption/templates/settings-personal.php
index ce8cf6aec281c079b1593fb8fdd84dd957cb1511..17123a154d97b4dd39a47fed25397a11883bd89a 100644
--- a/apps/files_encryption/templates/settings-personal.php
+++ b/apps/files_encryption/templates/settings-personal.php
@@ -1,11 +1,11 @@
 <form id="encryption" class="section">
 	<h2><?php p( $l->t( 'Encryption' ) ); ?></h2>
 
-	<?php if ( $_["initialized"] === \OCA\Encryption\Session::NOT_INITIALIZED ): ?>
+	<?php if ( $_["initialized"] === \OCA\Files_Encryption\Session::NOT_INITIALIZED ): ?>
 
 	<?php p($l->t("Encryption App is enabled but your keys are not initialized, please log-out and log-in again")); ?>
 
-	<?php elseif ( $_["initialized"] === \OCA\Encryption\Session::INIT_EXECUTED ): ?>
+	<?php elseif ( $_["initialized"] === \OCA\Files_Encryption\Session::INIT_EXECUTED ): ?>
 		<p>
 			<a name="changePKPasswd" />
 			<label for="changePrivateKeyPasswd">
@@ -37,7 +37,7 @@
 			<span class="msg"></span>
 		</p>
 
-	<?php elseif ( $_["recoveryEnabled"] && $_["privateKeySet"] &&  $_["initialized"] === \OCA\Encryption\Session::INIT_SUCCESSFUL ): ?>
+	<?php elseif ( $_["recoveryEnabled"] && $_["privateKeySet"] &&  $_["initialized"] === \OCA\Files_Encryption\Session::INIT_SUCCESSFUL ): ?>
 		<br />
 		<p id="userEnableRecovery">
 			<label for="userEnableRecovery"><?php p( $l->t( "Enable password recovery:" ) ); ?></label>
diff --git a/apps/files_encryption/tests/crypt.php b/apps/files_encryption/tests/crypt.php
index ab2ce066cdbaae18b218aafafc84fee5eb9e12c7..2a60340405174a77559ce381c39526c34e7517a4 100755
--- a/apps/files_encryption/tests/crypt.php
+++ b/apps/files_encryption/tests/crypt.php
@@ -7,7 +7,7 @@
  * See the COPYING-README file.
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Crypt;
 
 /**
  * Class Test_Encryption_Crypt
@@ -52,9 +52,9 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->legacyData = __DIR__ . '/legacy-text.txt';
 		$this->legacyEncryptedData = __DIR__ . '/legacy-encrypted-text.txt';
 		$this->legacyEncryptedDataKey = __DIR__ . '/encryption.key';
-		$this->randomKey = Encryption\Crypt::generateKey();
+		$this->randomKey = Crypt::generateKey();
 
-		$keypair = Encryption\Crypt::createKeypair();
+		$keypair = Crypt::createKeypair();
 		$this->genPublicKey = $keypair['publicKey'];
 		$this->genPrivateKey = $keypair['privateKey'];
 
@@ -95,7 +95,7 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 
 		# TODO: use more accurate (larger) string length for test confirmation
 
-		$key = Encryption\Crypt::generateKey();
+		$key = Crypt::generateKey();
 
 		$this->assertTrue(strlen($key) > 16);
 
@@ -104,16 +104,16 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 	public function testDecryptPrivateKey() {
 
 		// test successful decrypt
-		$crypted = Encryption\Crypt::symmetricEncryptFileContent($this->genPrivateKey, 'hat');
+		$crypted = Crypt::symmetricEncryptFileContent($this->genPrivateKey, 'hat');
 
-		$header = Encryption\Crypt::generateHeader();
+		$header = Crypt::generateHeader();
 
-		$decrypted = Encryption\Crypt::decryptPrivateKey($header . $crypted, 'hat');
+		$decrypted = Crypt::decryptPrivateKey($header . $crypted, 'hat');
 
 		$this->assertEquals($this->genPrivateKey, $decrypted);
 
 		//test private key decrypt with wrong password
-		$wrongPasswd = Encryption\Crypt::decryptPrivateKey($crypted, 'hat2');
+		$wrongPasswd = Crypt::decryptPrivateKey($crypted, 'hat2');
 
 		$this->assertEquals(false, $wrongPasswd);
 
@@ -127,12 +127,12 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 
 		# TODO: search in keyfile for actual content as IV will ensure this test always passes
 
-		$crypted = Encryption\Crypt::symmetricEncryptFileContent($this->dataShort, 'hat');
+		$crypted = Crypt::symmetricEncryptFileContent($this->dataShort, 'hat');
 
 		$this->assertNotEquals($this->dataShort, $crypted);
 
 
-		$decrypt = Encryption\Crypt::symmetricDecryptFileContent($crypted, 'hat');
+		$decrypt = Crypt::symmetricDecryptFileContent($crypted, 'hat');
 
 		$this->assertEquals($this->dataShort, $decrypt);
 
@@ -145,12 +145,12 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 
 		# TODO: search in keyfile for actual content as IV will ensure this test always passes
 
-		$crypted = Encryption\Crypt::symmetricEncryptFileContent($this->dataShort, 'hat', 'AES-128-CFB');
+		$crypted = Crypt::symmetricEncryptFileContent($this->dataShort, 'hat', 'AES-128-CFB');
 
 		$this->assertNotEquals($this->dataShort, $crypted);
 
 
-		$decrypt = Encryption\Crypt::symmetricDecryptFileContent($crypted, 'hat', 'AES-128-CFB');
+		$decrypt = Crypt::symmetricDecryptFileContent($crypted, 'hat', 'AES-128-CFB');
 
 		$this->assertEquals($this->dataShort, $decrypt);
 
@@ -348,7 +348,7 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 
 		// remove the header to check if we can also decrypt old files without a header,
 		//  this files should fall back to AES-128
-		$cryptedWithoutHeader = substr($retreivedCryptedFile, Encryption\Crypt::BLOCKSIZE);
+		$cryptedWithoutHeader = substr($retreivedCryptedFile, Crypt::BLOCKSIZE);
 		$this->view->file_put_contents($this->userId . '/files/' . $filename, $cryptedWithoutHeader);
 
 		// Re-enable proxy - our work is done
@@ -367,13 +367,13 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	public function testIsEncryptedContent() {
 
-		$this->assertFalse(Encryption\Crypt::isCatfileContent($this->dataUrl));
+		$this->assertFalse(Crypt::isCatfileContent($this->dataUrl));
 
-		$this->assertFalse(Encryption\Crypt::isCatfileContent($this->legacyEncryptedData));
+		$this->assertFalse(Crypt::isCatfileContent($this->legacyEncryptedData));
 
-		$keyfileContent = Encryption\Crypt::symmetricEncryptFileContent($this->dataUrl, 'hat', 'AES-128-CFB');
+		$keyfileContent = Crypt::symmetricEncryptFileContent($this->dataUrl, 'hat', 'AES-128-CFB');
 
-		$this->assertTrue(Encryption\Crypt::isCatfileContent($keyfileContent));
+		$this->assertTrue(Crypt::isCatfileContent($keyfileContent));
 
 	}
 
@@ -384,7 +384,7 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 
 		# TODO: search in keyfile for actual content as IV will ensure this test always passes
 
-		$pair1 = Encryption\Crypt::createKeypair();
+		$pair1 = Crypt::createKeypair();
 
 		$this->assertEquals(2, count($pair1));
 
@@ -393,12 +393,12 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->assertTrue(strlen($pair1['privateKey']) > 1);
 
 
-		$crypted = Encryption\Crypt::multiKeyEncrypt($this->dataShort, array($pair1['publicKey']));
+		$crypted = Crypt::multiKeyEncrypt($this->dataShort, array($pair1['publicKey']));
 
 		$this->assertNotEquals($this->dataShort, $crypted['data']);
 
 
-		$decrypt = Encryption\Crypt::multiKeyDecrypt($crypted['data'], $crypted['keys'][0], $pair1['privateKey']);
+		$decrypt = Crypt::multiKeyDecrypt($crypted['data'], $crypted['keys'][0], $pair1['privateKey']);
 
 		$this->assertEquals($this->dataShort, $decrypt);
 
@@ -529,7 +529,7 @@ class Test_Encryption_Crypt extends \OCA\Files_Encryption\Tests\TestCase {
 		// relogin
 		$params['uid'] = $this->userId;
 		$params['password'] = 'test';
-		OCA\Encryption\Hooks::login($params);
+		OCA\Files_Encryption\Hooks::login($params);
 
 		// Get file decrypted contents
 		$newDecrypt = file_get_contents('crypt:///' . $this->userId . '/files/' . $filename);
diff --git a/apps/files_encryption/tests/helper.php b/apps/files_encryption/tests/helper.php
index 88ba9f20d53bbdce234e51035dffdcf981261789..a76786118745a44f09e7e96a5802cc80a95f144e 100644
--- a/apps/files_encryption/tests/helper.php
+++ b/apps/files_encryption/tests/helper.php
@@ -6,7 +6,7 @@
  * See the COPYING-README file.
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Helper;
 
 /**
  * Class Test_Encryption_Helper
@@ -30,11 +30,11 @@ class Test_Encryption_Helper extends \OCA\Files_Encryption\Tests\TestCase {
 
 	public static function setupHooks() {
 		// Filesystem related hooks
-		\OCA\Encryption\Helper::registerFilesystemHooks();
+		Helper::registerFilesystemHooks();
 
 		// clear and register hooks
 		\OC_FileProxy::clearProxies();
-		\OC_FileProxy::register(new OCA\Encryption\Proxy());
+		\OC_FileProxy::register(new \OCA\Files_Encryption\Proxy());
 	}
 
 	public static function tearDownAfterClass() {
@@ -49,13 +49,13 @@ class Test_Encryption_Helper extends \OCA\Files_Encryption\Tests\TestCase {
 		$partFilename = 'testfile.txt.part';
 		$filename = 'testfile.txt';
 
-		$this->assertTrue(Encryption\Helper::isPartialFilePath($partFilename));
+		$this->assertTrue(Helper::isPartialFilePath($partFilename));
 
-		$this->assertEquals('testfile.txt', Encryption\Helper::stripPartialFileExtension($partFilename));
+		$this->assertEquals('testfile.txt', Helper::stripPartialFileExtension($partFilename));
 
-		$this->assertFalse(Encryption\Helper::isPartialFilePath($filename));
+		$this->assertFalse(Helper::isPartialFilePath($filename));
 
-		$this->assertEquals('testfile.txt', Encryption\Helper::stripPartialFileExtension($filename));
+		$this->assertEquals('testfile.txt', Helper::stripPartialFileExtension($filename));
 	}
 
 
@@ -67,13 +67,13 @@ class Test_Encryption_Helper extends \OCA\Files_Encryption\Tests\TestCase {
 		$partFilename = 'testfile.txt.ocTransferId643653835.part';
 		$filename = 'testfile.txt';
 
-		$this->assertTrue(Encryption\Helper::isPartialFilePath($partFilename));
+		$this->assertTrue(Helper::isPartialFilePath($partFilename));
 
-		$this->assertEquals('testfile.txt', Encryption\Helper::stripPartialFileExtension($partFilename));
+		$this->assertEquals('testfile.txt', Helper::stripPartialFileExtension($partFilename));
 
-		$this->assertFalse(Encryption\Helper::isPartialFilePath($filename));
+		$this->assertFalse(Helper::isPartialFilePath($filename));
 
-		$this->assertEquals('testfile.txt', Encryption\Helper::stripPartialFileExtension($filename));
+		$this->assertEquals('testfile.txt', Helper::stripPartialFileExtension($filename));
 	}
 
 	function testGetPathToRealFile() {
@@ -85,8 +85,8 @@ class Test_Encryption_Helper extends \OCA\Files_Encryption\Tests\TestCase {
 		$versionPath = "/user/files_versions/foo/bar/test.txt.v456756835";
 		$cachePath = "/user/cache/transferid636483/foo/bar/test.txt";
 
-		$this->assertEquals($relativePath, Encryption\Helper::getPathToRealFile($versionPath));
-		$this->assertEquals($relativePath, Encryption\Helper::getPathToRealFile($cachePath));
+		$this->assertEquals($relativePath, Helper::getPathToRealFile($versionPath));
+		$this->assertEquals($relativePath, Helper::getPathToRealFile($cachePath));
 	}
 
 	function testGetUser() {
@@ -100,17 +100,17 @@ class Test_Encryption_Helper extends \OCA\Files_Encryption\Tests\TestCase {
 		self::loginHelper(self::TEST_ENCRYPTION_HELPER_USER1);
 
 		// if we are logged-in every path should return the currently logged-in user
-		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Encryption\Helper::getUser($path3));
+		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Helper::getUser($path3));
 
 		// now log out
 		self::logoutHelper();
 
 		// now we should only get the user from /user/files and user/cache paths
-		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Encryption\Helper::getUser($path1));
-		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Encryption\Helper::getUser($path2));
+		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Helper::getUser($path1));
+		$this->assertEquals(self::TEST_ENCRYPTION_HELPER_USER1, Helper::getUser($path2));
 
-		$this->assertFalse(Encryption\Helper::getUser($path3));
-		$this->assertFalse(Encryption\Helper::getUser($path4));
+		$this->assertFalse(Helper::getUser($path3));
+		$this->assertFalse(Helper::getUser($path4));
 
 		// Log-in again
 		self::loginHelper(\Test_Encryption_Helper::TEST_ENCRYPTION_HELPER_USER1);
diff --git a/apps/files_encryption/tests/hooks.php b/apps/files_encryption/tests/hooks.php
index d5a30f5074aea17c0d07a1e48357267560e61b33..b4a28dd24ab966b5a073af19e266646450226254 100644
--- a/apps/files_encryption/tests/hooks.php
+++ b/apps/files_encryption/tests/hooks.php
@@ -20,7 +20,9 @@
  *
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Crypt;
+use OCA\Files_Encryption\Hooks;
+use OCA\Files_Encryption\Keymanager;
 
 /**
  * Class Test_Encryption_Hooks
@@ -104,7 +106,7 @@ class Test_Encryption_Hooks extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->assertTrue(is_array($row));
 
 		// disabling the app should delete all user specific settings
-		\OCA\Encryption\Hooks::preDisable(array('app' => 'files_encryption'));
+		Hooks::preDisable(array('app' => 'files_encryption'));
 
 		// check if user specific settings for the encryption app are really gone
 		$query = \OC_DB::prepare('SELECT * FROM `*PREFIX*preferences` WHERE `appid` = ?');
@@ -407,35 +409,35 @@ class Test_Encryption_Hooks extends \OCA\Files_Encryption\Tests\TestCase {
 		$view = new \OC\Files\View();
 
 		// set user password for the first time
-		\OCA\Encryption\Hooks::postCreateUser(array('uid' => 'newUser', 'password' => 'newUserPassword'));
+		Hooks::postCreateUser(array('uid' => 'newUser', 'password' => 'newUserPassword'));
 
-		$this->assertTrue($view->file_exists(\OCA\Encryption\Keymanager::getPublicKeyPath() . '/newUser.publicKey'));
+		$this->assertTrue($view->file_exists(Keymanager::getPublicKeyPath() . '/newUser.publicKey'));
 		$this->assertTrue($view->file_exists('newUser/files_encryption/newUser.privateKey'));
 
 		// check if we are able to decrypt the private key
-		$encryptedKey = \OCA\Encryption\Keymanager::getPrivateKey($view, 'newUser');
-		$privateKey = \OCA\Encryption\Crypt::decryptPrivateKey($encryptedKey, 'newUserPassword');
+		$encryptedKey = Keymanager::getPrivateKey($view, 'newUser');
+		$privateKey = Crypt::decryptPrivateKey($encryptedKey, 'newUserPassword');
 		$this->assertTrue(is_string($privateKey));
 
 		// change the password before the user logged-in for the first time,
 		// we can replace the encryption keys
-		\OCA\Encryption\Hooks::setPassphrase(array('uid' => 'newUser', 'password' => 'passwordChanged'));
+		Hooks::setPassphrase(array('uid' => 'newUser', 'password' => 'passwordChanged'));
 
-		$encryptedKey = \OCA\Encryption\Keymanager::getPrivateKey($view, 'newUser');
-		$privateKey = \OCA\Encryption\Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged');
+		$encryptedKey = Keymanager::getPrivateKey($view, 'newUser');
+		$privateKey = Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged');
 		$this->assertTrue(is_string($privateKey));
 
 		// now create a files folder to simulate a already used account
 		$view->mkdir('/newUser/files');
 
 		// change the password after the user logged in, now the password should not change
-		\OCA\Encryption\Hooks::setPassphrase(array('uid' => 'newUser', 'password' => 'passwordChanged2'));
+		Hooks::setPassphrase(array('uid' => 'newUser', 'password' => 'passwordChanged2'));
 
-		$encryptedKey = \OCA\Encryption\Keymanager::getPrivateKey($view, 'newUser');
-		$privateKey = \OCA\Encryption\Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged2');
+		$encryptedKey = Keymanager::getPrivateKey($view, 'newUser');
+		$privateKey = Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged2');
 		$this->assertFalse($privateKey);
 
-		$privateKey = \OCA\Encryption\Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged');
+		$privateKey = Crypt::decryptPrivateKey($encryptedKey, 'passwordChanged');
 		$this->assertTrue(is_string($privateKey));
 
 	}
diff --git a/apps/files_encryption/tests/migration.php b/apps/files_encryption/tests/migration.php
index 21c4e354c299872e502755398a82157ee4a5a267..3abe322235c78333ebd68a1b23b1839472e99109 100644
--- a/apps/files_encryption/tests/migration.php
+++ b/apps/files_encryption/tests/migration.php
@@ -21,8 +21,7 @@
  *
  */
 
-use OCA\Encryption;
-use OCA\Files_Encryption\Migration;
+use OCA\Files_Encryption\Helper;
 
 class Test_Migration extends \OCA\Files_Encryption\Tests\TestCase {
 
@@ -60,8 +59,8 @@ class Test_Migration extends \OCA\Files_Encryption\Tests\TestCase {
 	public function setUp() {
 		$this->loginHelper(self::TEST_ENCRYPTION_MIGRATION_USER1);
 		$this->view = new \OC\Files\View();
-		$this->public_share_key_id = Encryption\Helper::getPublicShareKeyId();
-		$this->recovery_key_id = Encryption\Helper::getRecoveryKeyId();
+		$this->public_share_key_id = Helper::getPublicShareKeyId();
+		$this->recovery_key_id = Helper::getRecoveryKeyId();
 		if (OC_DB::tableExists('encryption_test')) {
 			OC_DB::dropTable('encryption_test');
 		}
diff --git a/apps/files_encryption/tests/proxy.php b/apps/files_encryption/tests/proxy.php
index 72a9a9a5551109425d0c33005ed7ceb25a82b152..3cc668e63613c336f0ae642ab95c7b66c14f7756 100644
--- a/apps/files_encryption/tests/proxy.php
+++ b/apps/files_encryption/tests/proxy.php
@@ -20,8 +20,6 @@
  *
  */
 
-use OCA\Encryption;
-
 /**
  * Class Test_Encryption_Proxy
  * this class provide basic proxy app tests
@@ -153,7 +151,7 @@ class Test_Encryption_Proxy extends \OCA\Files_Encryption\Tests\TestCase {
 /**
  * Dummy class to make protected methods available for testing
  */
-class DummyProxy extends \OCA\Encryption\Proxy {
+class DummyProxy extends \OCA\Files_Encryption\Proxy {
 	public function isExcludedPathTesting($path, $uid) {
 		return $this->isExcludedPath($path, $uid);
 	}
diff --git a/apps/files_encryption/tests/share.php b/apps/files_encryption/tests/share.php
index f827017569f94ebd8dd600d090a87aeb94186514..0eaff6bf87f56a1cb80cb9d0389fbb6edc03159f 100755
--- a/apps/files_encryption/tests/share.php
+++ b/apps/files_encryption/tests/share.php
@@ -20,7 +20,10 @@
  *
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Helper;
+use OCA\Files_Encryption\Hooks;
+use OCA\Files_Encryption\Keymanager;
+use OCA\Files_Encryption\Util;
 
 /**
  * Class Test_Encryption_Share
@@ -651,13 +654,13 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		// login as admin
 		self::loginHelper(\Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1);
 
-		\OCA\Encryption\Helper::adminEnableRecovery(null, 'test123');
+		Helper::adminEnableRecovery(null, 'test123');
 		$recoveryKeyId = \OC::$server->getAppConfig()->getValue('files_encryption', 'recoveryKeyId');
 
 		// login as admin
 		self::loginHelper(\Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1);
 
-		$util = new \OCA\Encryption\Util(new \OC\Files\View('/'), \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1);
+		$util = new Util(new \OC\Files\View('/'), \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1);
 
 		// check if recovery password match
 		$this->assertTrue($util->checkRecoveryPassword('test123'));
@@ -744,8 +747,8 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 			. $this->subfolder . $this->subsubfolder . '/'
 			. $this->filename . '/' . $recoveryKeyId . '.shareKey'));
 
-		$this->assertTrue(\OCA\Encryption\Helper::adminEnableRecovery(null, 'test123'));
-		$this->assertTrue(\OCA\Encryption\Helper::adminDisableRecovery('test123'));
+		$this->assertTrue(Helper::adminEnableRecovery(null, 'test123'));
+		$this->assertTrue(Helper::adminDisableRecovery('test123'));
 		$this->assertEquals(0, \OC::$server->getAppConfig()->getValue('files_encryption', 'recoveryAdminEnabled'));
 	}
 
@@ -757,7 +760,7 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		// login as admin
 		self::loginHelper(\Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1);
 
-		$result = \OCA\Encryption\Helper::adminEnableRecovery(null, 'test123');
+		$result = Helper::adminEnableRecovery(null, 'test123');
 		$this->assertTrue($result);
 
 		$recoveryKeyId = \OC::$server->getAppConfig()->getValue('files_encryption', 'recoveryKeyId');
@@ -765,7 +768,7 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		// login as user2
 		self::loginHelper(\Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2);
 
-		$util = new \OCA\Encryption\Util(new \OC\Files\View('/'), \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2);
+		$util = new Util(new \OC\Files\View('/'), \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2);
 
 		// enable recovery for admin
 		$this->assertTrue($util->setRecoveryForUser(1));
@@ -814,7 +817,7 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		$params = array('uid' => \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2,
 			'password' => 'test',
 			'recoveryPassword' => 'test123');
-		\OCA\Encryption\Hooks::setPassphrase($params);
+		Hooks::setPassphrase($params);
 
 		// login as user2
 		self::loginHelper(\Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2, false, 'test');
@@ -853,7 +856,7 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		// enable recovery for admin
 		$this->assertTrue($util->setRecoveryForUser(0));
 
-		\OCA\Encryption\Helper::adminDisableRecovery('test123');
+		Helper::adminDisableRecovery('test123');
 		$this->assertEquals(0, \OC::$server->getAppConfig()->getValue('files_encryption', 'recoveryAdminEnabled'));
 
 		//clean up, reset passwords
@@ -861,7 +864,7 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		$params = array('uid' => \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2,
 			'password' => \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER2,
 			'recoveryPassword' => 'test123');
-		\OCA\Encryption\Hooks::setPassphrase($params);
+		Hooks::setPassphrase($params);
 	}
 
 	/**
@@ -892,8 +895,8 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->assertGreaterThan(0, $fileInfo['unencrypted_size']);
 
 		// break users public key
-		$this->view->rename(\OCA\Encryption\Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey',
-			\OCA\Encryption\Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey_backup');
+		$this->view->rename(Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey',
+			Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey_backup');
 
 		// re-enable the file proxy
 		\OC_FileProxy::$enabled = $proxyStatus;
@@ -920,8 +923,8 @@ class Test_Encryption_Share extends \OCA\Files_Encryption\Tests\TestCase {
 
 		// break user1 public key
 		$this->view->rename(
-			\OCA\Encryption\Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey_backup',
-			\OCA\Encryption\Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey');
+			Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey_backup',
+			Keymanager::getPublicKeyPath() . '/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER3 . '.publicKey');
 
 		// remove share file
 		$this->view->unlink('/' . \Test_Encryption_Share::TEST_ENCRYPTION_SHARE_USER1 . '/files_encryption/keys/'
diff --git a/apps/files_encryption/tests/stream.php b/apps/files_encryption/tests/stream.php
index f4824935ca03e397c35d32614a3a47cae24cec13..08d4ddcf5b819dda834c299f511ff6b5610b5a6d 100644
--- a/apps/files_encryption/tests/stream.php
+++ b/apps/files_encryption/tests/stream.php
@@ -20,8 +20,6 @@
  *
  */
 
-use OCA\Encryption;
-
 /**
  * Class Test_Encryption_Stream
  * this class provide basic stream tests
@@ -208,7 +206,7 @@ class Test_Encryption_Stream extends \OCA\Files_Encryption\Tests\TestCase {
 
 		file_put_contents($tmpFilename, $encryptedContent);
 
-		\OCA\Encryption\Helper::addTmpFileToMapper($tmpFilename, $filename);
+		\OCA\Files_Encryption\Helper::addTmpFileToMapper($tmpFilename, $filename);
 
 		// try to read the file from /tmp
 		$handle = fopen("crypt://".$tmpFilename, "r");
diff --git a/apps/files_encryption/tests/testcase.php b/apps/files_encryption/tests/testcase.php
index 743a876ab45468f6e80299e8584d3b491f0b322b..84b728d4aaa418240af5c9c901ba4bc44850d433 100644
--- a/apps/files_encryption/tests/testcase.php
+++ b/apps/files_encryption/tests/testcase.php
@@ -8,7 +8,7 @@
 
 namespace OCA\Files_Encryption\Tests;
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Helper;
 
 /**
  * Class Test_Encryption_TestCase
@@ -42,7 +42,7 @@ abstract class TestCase extends \Test\TestCase {
 		if ($loadEncryption) {
 			$params['uid'] = $user;
 			$params['password'] = $password;
-			\OCA\Encryption\Hooks::login($params);
+			\OCA\Files_Encryption\Hooks::login($params);
 		}
 	}
 
@@ -59,16 +59,16 @@ abstract class TestCase extends \Test\TestCase {
 		\OC_User::clearBackends();
 		\OC_User::useBackend('database');
 
-		\OCA\Encryption\Helper::registerFilesystemHooks();
-		\OCA\Encryption\Helper::registerUserHooks();
-		\OCA\Encryption\Helper::registerShareHooks();
+		Helper::registerFilesystemHooks();
+		Helper::registerUserHooks();
+		Helper::registerShareHooks();
 
 		\OC::registerShareHooks();
 		\OCP\Util::connectHook('OC_Filesystem', 'setup', '\OC\Files\Storage\Shared', 'setup');
 
 		// clear and register hooks
 		\OC_FileProxy::clearProxies();
-		\OC_FileProxy::register(new \OCA\Encryption\Proxy());
+		\OC_FileProxy::register(new \OCA\Files_Encryption\Proxy());
 	}
 
 	public static function tearDownAfterClass() {
diff --git a/apps/files_encryption/tests/trashbin.php b/apps/files_encryption/tests/trashbin.php
index de5b8bd6edb0229cde30fe7751a083163d8be6cb..d8af31760ee8d987cd82bcb3e68af7d37d7e9b86 100755
--- a/apps/files_encryption/tests/trashbin.php
+++ b/apps/files_encryption/tests/trashbin.php
@@ -20,8 +20,6 @@
  *
  */
 
-use OCA\Encryption;
-
 /**
  * Class Test_Encryption_Trashbin
  * this class provide basic trashbin app tests
diff --git a/apps/files_encryption/tests/webdav.php b/apps/files_encryption/tests/webdav.php
index a04a76212915d59caa8e42402c7f3c98e3389899..e3c92a4333cf68b1699b0d330bfa770eccd1bead 100755
--- a/apps/files_encryption/tests/webdav.php
+++ b/apps/files_encryption/tests/webdav.php
@@ -20,7 +20,7 @@
  *
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Crypt;
 
 /**
  * Class Test_Encryption_Webdav
@@ -138,7 +138,7 @@ class Test_Encryption_Webdav extends \OCA\Files_Encryption\Tests\TestCase {
 		\OC_FileProxy::$enabled = $proxyStatus;
 
 		// check if encrypted content is valid
-		$this->assertTrue(Encryption\Crypt::isCatfileContent($encryptedContent));
+		$this->assertTrue(Crypt::isCatfileContent($encryptedContent));
 
 		// get decrypted file contents
 		$decrypt = file_get_contents('crypt:///' . $this->userId . '/files' . $filename);
diff --git a/apps/files_encryption/tests/keymanager.php b/apps/files_encryption/tests/keymanager.php
index 21f03839430b73df93857fd9ee85b2c1f6f8d2bc..f10940e441e940fb85070e9047ccf32c65bf217d 100644
--- a/apps/files_encryption/tests/keymanager.php
+++ b/apps/files_encryption/tests/keymanager.php
@@ -6,7 +6,9 @@
  * See the COPYING-README file.
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Crypt;
+use OCA\Files_Encryption\Keymanager;
+use OCA\Files_Encryption\Util;
 
 /**
  * Class Test_Encryption_Keymanager
@@ -50,9 +52,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->dataUrl = __DIR__ . '/../lib/crypt.php';
 		$this->legacyData = __DIR__ . '/legacy-text.txt';
 		$this->legacyEncryptedData = __DIR__ . '/legacy-encrypted-text.txt';
-		$this->randomKey = Encryption\Crypt::generateKey();
+		$this->randomKey = Crypt::generateKey();
 
-		$keypair = Encryption\Crypt::createKeypair();
+		$keypair = Crypt::createKeypair();
 		$this->genPublicKey = $keypair['publicKey'];
 		$this->genPrivateKey = $keypair['privateKey'];
 
@@ -89,9 +91,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	function testGetPrivateKey() {
 
-		$key = Encryption\Keymanager::getPrivateKey($this->view, $this->userId);
+		$key = Keymanager::getPrivateKey($this->view, $this->userId);
 
-		$privateKey = Encryption\Crypt::decryptPrivateKey($key, $this->pass);
+		$privateKey = Crypt::decryptPrivateKey($key, $this->pass);
 
 		$res = openssl_pkey_get_private($privateKey);
 
@@ -108,7 +110,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	function testGetPublicKey() {
 
-		$publiceKey = Encryption\Keymanager::getPublicKey($this->view, $this->userId);
+		$publiceKey = Keymanager::getPublicKey($this->view, $this->userId);
 
 		$res = openssl_pkey_get_public($publiceKey);
 
@@ -128,7 +130,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$file = 'unittest-' . $this->getUniqueID() . '.txt';
 
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		// Disable encryption proxy to prevent recursive calls
 		$proxyStatus = \OC_FileProxy::$enabled;
@@ -136,7 +138,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$this->view->file_put_contents($this->userId . '/files/' . $file, $this->dataShort);
 
-		Encryption\Keymanager::setFileKey($this->view, $util, $file, $key);
+		Keymanager::setFileKey($this->view, $util, $file, $key);
 
 		$this->assertTrue($this->view->file_exists('/' . $this->userId . '/files_encryption/keys/' . $file . '/fileKey'));
 
@@ -154,7 +156,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$key = "dummy key";
 
-		Encryption\Keymanager::setPrivateKey($key, 'dummyUser');
+		Keymanager::setPrivateKey($key, 'dummyUser');
 
 		$this->assertTrue($this->view->file_exists('/dummyUser/files_encryption/dummyUser.privateKey'));
 
@@ -169,13 +171,13 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$key = "dummy key";
 		$keyName = "myDummyKey";
-		$encHeader = Encryption\Crypt::generateHeader();
+		$encHeader = Crypt::generateHeader();
 
-		Encryption\Keymanager::setPrivateSystemKey($key, $keyName);
+		Keymanager::setPrivateSystemKey($key, $keyName);
 
 		$this->assertTrue($this->view->file_exists('/files_encryption/' . $keyName . '.privateKey'));
 
-		$result = Encryption\Keymanager::getPrivateSystemKey($keyName);
+		$result = Keymanager::getPrivateSystemKey($keyName);
 
 		$this->assertSame($encHeader . $key, $result);
 
@@ -189,7 +191,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	function testGetUserKeys() {
 
-		$keys = Encryption\Keymanager::getUserKeys($this->view, $this->userId);
+		$keys = Keymanager::getUserKeys($this->view, $this->userId);
 
 		$resPublic = openssl_pkey_get_public($keys['publicKey']);
 
@@ -199,7 +201,7 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$this->assertArrayHasKey('key', $sslInfoPublic);
 
-		$privateKey = Encryption\Crypt::decryptPrivateKey($keys['privateKey'], $this->pass);
+		$privateKey = Crypt::decryptPrivateKey($keys['privateKey'], $this->pass);
 
 		$resPrivate = openssl_pkey_get_private($privateKey);
 
@@ -247,9 +249,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->view->file_put_contents('/'.Test_Encryption_Keymanager::TEST_USER.'/files_encryption/keys/folder1/subfolder/subsubfolder/file2/user3.shareKey', 'data');
 
 		// recursive delete share keys from user1 and user2
-		Encryption\Keymanager::delShareKey($this->view,
+		Keymanager::delShareKey($this->view,
 				array('user1', 'user2', Test_Encryption_Keymanager::TEST_USER),
-				Encryption\Keymanager::getKeyPath($this->view, new Encryption\Util($this->view, Test_Encryption_Keymanager::TEST_USER), '/folder1'),
+				Keymanager::getKeyPath($this->view, new Util($this->view, Test_Encryption_Keymanager::TEST_USER), '/folder1'),
 				Test_Encryption_Keymanager::TEST_USER,
 				'/folder1');
 
@@ -315,9 +317,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->view->file_put_contents('/'.Test_Encryption_Keymanager::TEST_USER.'/files_encryption/share-keys/folder1/existingFile.txt.' . Test_Encryption_Keymanager::TEST_USER . '.shareKey', 'data');
 
 		// recursive delete share keys from user1 and user2
-		Encryption\Keymanager::delShareKey($this->view,
+		Keymanager::delShareKey($this->view,
 				array('user1', 'user2', Test_Encryption_Keymanager::TEST_USER),
-				Encryption\Keymanager::getKeyPath($this->view, new Encryption\Util($this->view, Test_Encryption_Keymanager::TEST_USER), '/folder1/existingFile.txt'),
+				Keymanager::getKeyPath($this->view, new Util($this->view, Test_Encryption_Keymanager::TEST_USER), '/folder1/existingFile.txt'),
 				Test_Encryption_Keymanager::TEST_USER,
 				'/folder1/existingFile.txt');
 
@@ -356,9 +358,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 }
 
 /**
  * dummy class to access protected methods of \OCA\Encryption\Keymanager for testing
  */
-class TestProtectedKeymanagerMethods extends \OCA\Encryption\Keymanager {
+class TestProtectedKeymanagerMethods extends \OCA\Files_Encryption\Keymanager {
 
 	/**
 	 * @param \OC\Files\View $view relative to data/
@@ -356,9 +358,9 @@ class Test_Encryption_Keymanager extends \OCA\Files_Encryption\Tests\TestCase {
 
 /**
- * dummy class to access protected methods of \OCA\Encryption\Keymanager for testing
+ * dummy class to access protected methods of \OCA\Files_Encryption\Keymanager for testing
  */
diff --git a/apps/files_encryption/tests/util.php b/apps/files_encryption/tests/util.php
index 2d58db2128c7bca14d7573ebaf9d39d35484bd83..8496772a1352fbac64cbe0e97fa52c787bdb2f84 100755
--- a/apps/files_encryption/tests/util.php
+++ b/apps/files_encryption/tests/util.php
@@ -6,7 +6,9 @@
  * See the COPYING-README file.
  */
 
-use OCA\Encryption;
+use OCA\Files_Encryption\Crypt;
+use OCA\Files_Encryption\Keymanager;
+use OCA\Files_Encryption\Util;
 
 /**
  * Class Test_Encryption_Util
@@ -31,7 +33,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 	public $publicKeyPath;
 	public $privateKeyPath;
 	/**
-	 * @var \OCA\Encryption\Util
+	 * @var \OCA\Files_Encryption\Util
 	 */
 	public $util;
 	public $dataShort;
@@ -74,12 +76,12 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->legacyEncryptedDataKey = __DIR__ . '/encryption.key';
 		$this->legacyKey = "30943623843030686906\0\0\0\0";
 
-		$keypair = Encryption\Crypt::createKeypair();
+		$keypair = Crypt::createKeypair();
 
 		$this->genPublicKey = $keypair['publicKey'];
 		$this->genPrivateKey = $keypair['privateKey'];
 
-		$this->publicKeyDir = \OCA\Encryption\Keymanager::getPublicKeyPath();
+		$this->publicKeyDir = Keymanager::getPublicKeyPath();
 		$this->encryptionDir = '/' . $this->userId . '/' . 'files_encryption';
 		$this->keysPath = $this->encryptionDir . '/' . 'keys';
 		$this->publicKeyPath =
@@ -89,7 +91,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 
 		$this->view = new \OC\Files\View('/');
 
-		$this->util = new Encryption\Util($this->view, $this->userId);
+		$this->util = new Util($this->view, $this->userId);
 
 		// remember files_trashbin state
 		$this->stateFilesTrashbin = OC_App::isEnabled('files_trashbin');
@@ -128,7 +130,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 	 * test that paths set during User construction are correct
 	 */
 	function testKeyPaths() {
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		$this->assertEquals($this->publicKeyDir, $util->getPath('publicKeyDir'));
 		$this->assertEquals($this->encryptionDir, $util->getPath('encryptionDir'));
@@ -144,7 +146,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	function testIsEncryptedPath() {
 
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		self::loginHelper($this->userId);
 
@@ -197,7 +199,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 //
 //		$params['uid'] = $this->userId;
 //		$params['password'] = $this->pass;
-//		$this->assertFalse(OCA\Encryption\Hooks::login($params));
+//		$this->assertFalse(OCA\Files_Encryption\Hooks::login($params));
 //
 //		$this->view->unlink($this->privateKeyPath);
 //	}
@@ -207,7 +209,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 	 */
 	function testRecoveryEnabledForUser() {
 
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		// Record the value so we can return it to it's original state later
 		$enabled = $util->recoveryEnabledForUser();
@@ -241,7 +243,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 		// Re-enable proxy - our work is done
 		\OC_FileProxy::$enabled = $proxyStatus;
 
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		list($fileOwnerUid, $file) = $util->getUidAndFilename($filename);
 
@@ -283,7 +285,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 	function testEncryptAll() {
 
 		$filename = "/encryptAll" . $this->getUniqueID() . ".txt";
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		// disable encryption to upload a unencrypted file
 		\OC_App::disable('files_encryption');
@@ -345,11 +347,11 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 			'password' => \OCP\User::getUser());
 
 		$view = new OC\Files\View('/');
-		$util = new \OCA\Encryption\Util($view, \OCP\User::getUser());
+		$util = new Util($view, \OCP\User::getUser());
 
 		$result = $util->initEncryption($params);
 
-		$this->assertTrue($result instanceof \OCA\Encryption\Session);
+		$this->assertTrue($result instanceof \OCA\Files_Encryption\Session);
 
 		$successful = $util->decryptAll();
 
@@ -401,7 +403,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 		$this->view->file_put_contents($encPath . '/keys/foo/fileKey', 'key');
 		$this->view->file_put_contents($encPath . '/keys/foo/user1.shareKey', 'share key');
 
-		$util = new \OCA\Encryption\Util($this->view, self::TEST_ENCRYPTION_UTIL_USER1);
+		$util = new Util($this->view, self::TEST_ENCRYPTION_UTIL_USER1);
 
 		$util->backupAllKeys('testBackupAllKeys');
 
@@ -427,7 +429,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 		$file1 = "/decryptAll1" . $this->getUniqueID() . ".txt";
 		$file2 = "/decryptAll2" . $this->getUniqueID() . ".txt";
 
-		$util = new Encryption\Util($this->view, $this->userId);
+		$util = new Util($this->view, $this->userId);
 
 		$this->view->file_put_contents($this->userId . '/files/' . $file1, $this->dataShort);
 		$this->view->file_put_contents($this->userId . '/files/' . $file2, $this->dataShort);
@@ -598,7 +600,7 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 		if ($loadEncryption) {
 			$params['uid'] = $user;
 			$params['password'] = $password;
-			OCA\Encryption\Hooks::login($params);
+			\OCA\Files_Encryption\Hooks::login($params);
 		}
 	}
 
@@ -625,9 +627,9 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 }
 
 /**
  * dummy class extends  \OCA\Encryption\Util to access protected methods for testing
  */
-class DummyUtilClass extends \OCA\Encryption\Util {
+class DummyUtilClass extends \OCA\Files_Encryption\Util {
 	public function testIsMountPointApplicableToUser($mount) {
 		return $this->isMountPointApplicableToUser($mount);
 	}
@@ -625,9 +627,9 @@ class Test_Encryption_Util extends \OCA\Files_Encryption\Tests\TestCase {
 
 /**
- * dummy class extends  \OCA\Encryption\Util to access protected methods for testing
+ * dummy class extends  \OCA\Files_Encryption\Util to access protected methods for testing
  */